# README #

## COMMING SOON ##

SpiceLib is a toolchain of python utilities design to interact with Spice Simulators:
 * LTSPICE
 * QSPICE
 * NGSPICE
 * XYCE

 This project is released by the author of the PyLTSpice library, extending it for usage of the above mentioned simulators. This library is intended for the users that need to execute simulations different simulators at the same time. 

## How to Install ##

`pip install spicelib `
